@@ -6,8 +6,6 @@ import os
 import sys
 import tempfile
 
-version = '21w21a'
-
 def error(message):
     print('Error! {}'.format(message), file=sys.stderr)
     sys.exit(1)
@@ -104,8 +102,6 @@ def main_options(parser):
     parser.add_argument('metadataOps', nargs=0, action='grouping')
     parser.add_argument('--force_fps_to', type=float, group='metadataOps',
         help='manually set the fps value for the input video if detection fails.')
-    parser.add_argument('--force_tracks_to', type=int, group='metadataOps',
-        help='manually set the number of tracks auto-editor thinks there are.')
 
     parser.add_argument('exportMediaOps', nargs=0, action='grouping')
     parser.add_argument('--video_bitrate', '-vb', default='unset', group='exportMediaOps',
@@ -146,12 +142,15 @@ def main_options(parser):
 
     parser.add_argument('--export_as_audio', '-exa', action='store_true',
         help='export as a WAV audio file.')
+
     parser.add_argument('--export_to_premiere', '-exp', action='store_true',
-        help='export as an XML file for Adobe Premiere Pro instead of outputting a media file.')
+        help='export as an XML file for Adobe Premiere Pro instead of making a media file.')
     parser.add_argument('--export_to_resolve', '-exr', action='store_true',
-        help='export as an XML file for DaVinci Resolve instead of outputting a media file.')
+        help='export as an XML file for DaVinci Resolve instead of making a media file.')
     parser.add_argument('--export_to_final_cut_pro', '-exf', action='store_true',
-        help='export as an XML file for Final Cut Pro instead of outputting a media file.')
+        help='export as an XML file for Final Cut Pro instead of making a media file.')
+    parser.add_argument('--export_to_shotcut', '-exs', action='store_true',
+        help='export as an XML timeline file for Shotcut instead of making a media file.')
     parser.add_argument('--export_as_json', action='store_true',
         help='export as a JSON file that can be read by auto-editor later.')
     parser.add_argument('--export_as_clip_sequence', '-excs', action='store_true',
@@ -255,16 +254,17 @@ def main_options(parser):
 
 
 def main():
+    import auto_editor
     import auto_editor.vanparse as vanparse
     import auto_editor.usefulFunctions as usefulFunctions
 
-    from auto_editor.usefulFunctions import Log, Timer, fNone
-    from auto_editor.ffwrapper import FFmpeg, FFprobe
-    from auto_editor.wavfile import read
+    from auto_editor.usefulFunctions import fNone
+    from auto_editor.utils.log import Log, Timer
+    from auto_editor.ffwrapper import FFmpeg
 
-    dirPath = os.path.dirname(os.path.realpath(__file__))
+    dir_path = os.path.dirname(os.path.realpath(__file__))
 
-    parser = vanparse.ArgumentParser('Auto-Editor', version,
+    parser = vanparse.ArgumentParser('Auto-Editor', auto_editor.version,
         description='\nAuto-Editor is an automatic video/audio creator and editor. '\
             'By default, it will detect silence and create a new video with those '\
             'sections cut out. By changing some of the options, you can export to a '\
@@ -272,85 +272,66 @@ def main():
             'the pacing of the cuts, and change the method of editing like using audio '\
             'loudness and video motion to judge making cuts.\nRun:\n    auto-editor '\
             '--help\n\nTo get the list of options.\n')
-    parser.add_argument('--help', '-h', action='store_true',
-        help='print info about the program or an option and exit.')
 
     subcommands = ['create', 'test', 'info', 'levels']
 
     if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
         if(sys.argv[1] == 'create'):
-            from auto_editor.subcommands.create import create, create_options
-            parser = create_options(parser)
-            args = parser.parse_args(sys.argv[2:], Log(), 'create')
-
-            ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, True, Log())
-            create(ffmpeg, args.input, args.output_file, args.frame_rate, args.duration,
-                args.width, args.height, Log())
+            from auto_editor.subcommands.create import create
+            create(sys.argv[2:])
 
         if(sys.argv[1] == 'test'):
             from auto_editor.subcommands.test import test
             test()
 
         if(sys.argv[1] == 'info'):
-            from auto_editor.subcommands.info import info, info_options
-            parser = info_options(parser)
-            args = parser.parse_args(sys.argv[2:], Log(), 'info')
+            from auto_editor.subcommands.info import info
+            info(sys.argv[2:])
 
-            log = Log()
-            ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, False, log)
-            ffprobe = FFprobe(dirPath, args.my_ffmpeg, False, log)
-            info(args.input, ffmpeg, ffprobe, args.fast, log)
         if(sys.argv[1] == 'levels'):
-            from auto_editor.subcommands.levels import levels, levels_options
-            parser = levels_options(parser)
-            args = parser.parse_args(sys.argv[2:], Log(), 'levels')
+            from auto_editor.subcommands.levels import levels
+            levels(sys.argv[2:])
 
-            TEMP = tempfile.mkdtemp()
-            log = Log(temp=TEMP)
-            ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, False, log)
-            ffprobe = FFprobe(dirPath, args.my_ffmpeg, False, log)
-            levels(args.input, args.track, args.output_file, ffmpeg, ffprobe, TEMP, log)
         sys.exit()
     else:
         parser = main_options(parser)
-        args = parser.parse_args(sys.argv[1:], Log(True), 'auto-editor')
+        args = parser.parse_args(sys.argv[1:], Log(), 'auto-editor')
 
     timer = Timer(args.quiet)
 
-    TEMP = tempfile.mkdtemp()
-    log = Log(args.debug, args.quiet, temp=TEMP)
-    log.debug('\nTemp Directory: {}'.format(TEMP))
-
-    ffmpeg = FFmpeg(dirPath, args.my_ffmpeg, args.show_ffmpeg_debug, log)
-    ffprobe = FFprobe(dirPath, args.my_ffmpeg, args.show_ffmpeg_debug, log)
-
     exporting_to_editor = (args.export_to_premiere or args.export_to_resolve or
-        args.export_to_final_cut_pro)
+        args.export_to_final_cut_pro or args.export_to_shotcut)
     making_data_file = exporting_to_editor or args.export_as_json
 
     is64bit = '64-bit' if sys.maxsize > 2**32 else '32-bit'
 
     if(args.debug and args.input == []):
         import platform
+        log = Log()
+        ffmpeg = FFmpeg(dir_path, args.my_ffmpeg, args.show_ffmpeg_debug, log)
 
         print('Python Version: {} {}'.format(platform.python_version(), is64bit))
         print('Platform: {} {}'.format(platform.system(), platform.release()))
-        print('Config File path: {}'.format(os.path.join(dirPath, 'config.txt')))
+        print('Config File path: {}'.format(os.path.join(dir_path, 'config.txt')))
         print('FFmpeg path: {}'.format(ffmpeg.getPath()))
         print('FFmpeg version: {}'.format(ffmpeg.getVersion()))
-        print('Auto-Editor version {}'.format(version))
-        log.cleanup()
+        print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
     if(is64bit == '32-bit'):
-        log.warning('You have the 32-bit version of Python, which may lead to ' \
+        log.warning('You have the 32-bit version of Python, which may lead to '\
             'memory crashes.')
 
     if(args.version):
-        print('Auto-Editor version {}'.format(version))
-        log.cleanup()
+        print('Auto-Editor version {}'.format(auto_editor.version))
         sys.exit()
 
+    TEMP = tempfile.mkdtemp()
+    log = Log(args.debug, args.quiet, temp=TEMP)
+    ffmpeg = FFmpeg(dir_path, args.my_ffmpeg, args.show_ffmpeg_debug, log)
+
+    log.debug('Temp Directory: {}'.format(TEMP))
+
     if(args.input == []):
         log.error('You need to give auto-editor an input file or folder so it can ' \
             'do the work for you.')
@@ -360,7 +341,7 @@ def main():
         args.export_as_clip_sequence].count(True) > 1):
         log.error('You must choose only one export option.')
 
-    if(making_data_file and (args.video_codec != 'copy' or
+    if(making_data_file and (args.video_codec != 'uncompressed' or
         args.constant_rate_factor != 'unset' or args.tune != 'unset')):
         log.warning('exportMediaOps options are not used when making a data file.')
 
@@ -388,6 +369,8 @@ def main():
         log.conwrite('Exporting to Final Cut Pro XML file.')
     elif(args.export_to_resolve):
         log.conwrite('Exporting to DaVinci Resolve XML file.')
+    elif(args.export_to_shotcut):
+        log.conwrite('Exporting to Shotcut XML Timeline file.')
     elif(args.export_as_audio):
         log.conwrite('Exporting as audio.')
     else:
@@ -412,24 +395,31 @@ def main():
     from auto_editor.validateInput import validInput
     inputList = validInput(args.input, ffmpeg, args, log)
 
-    # Figure out the output file names.
-    def newOutputName(oldFile, audio, final_cut_pro, data, json):
-        dotIndex = oldFile.rfind('.')
-        if(json):
-            return oldFile[:dotIndex] + '.json'
-        if(final_cut_pro):
-            return oldFile[:dotIndex] + '.fcpxml'
-        if(data):
-            return oldFile[:dotIndex] + '.xml'
-        if(audio):
-            return oldFile[:dotIndex] + '_ALTERED.wav'
-        return oldFile[:dotIndex] + '_ALTERED' + oldFile[dotIndex:]
+    def set_output_name(path, args):
+        dot_index = path.rfind('.')
+
+        if(dot_index == -1):
+            root = path
+        else:
+            root = path[:dot_index]
+
+        if(args.export_as_json):
+            return root + '.json'
+        if(args.export_to_final_cut_pro):
+            return root + '.fcpxml'
+        if(args.export_to_shotcut):
+            return root + '.mlt'
+        if(making_data_file):
+            return root + '.xml'
+        if(args.export_as_audio):
+            return root + '_ALTERED.wav'
+
+        ext = path[dot_index:]
+        return root + '_ALTERED' + ext
 
     if(len(args.output_file) < len(inputList)):
         for i in range(len(inputList) - len(args.output_file)):
-            args.output_file.append(newOutputName(inputList[i],
-                args.export_as_audio, args.export_to_final_cut_pro, making_data_file,
-                args.export_as_json))
+            args.output_file.append(set_output_name(inputList[i], args))
 
     if(args.combine_files):
         temp_file = os.path.join(TEMP, 'combined.mp4')
@@ -456,89 +446,72 @@ def main():
         '.acc', '.nfa', '.mka']
     sampleRate = None
 
+    from auto_editor.scipy.wavfile import read
+
     for i, INPUT_FILE in enumerate(inputList):
 
-        if(len(inputList) > 1):
-            log.conwrite('Working on {}'.format(INPUT_FILE))
+        inp = ffmpeg.file_info(INPUT_FILE)
 
-        fileFormat = INPUT_FILE[INPUT_FILE.rfind('.'):]
+        if(len(inputList) > 1):
+            log.conwrite('Working on {}'.format(inp.basename))
 
         chunks = None
-        if(fileFormat == '.json'):
-            log.debug('Reading .json file')
+        if(inp.ext == '.json'):
             from auto_editor.formats.make_json import read_json_cutlist
-            INPUT_FILE, chunks, speeds = read_json_cutlist(INPUT_FILE, version, log)
-            newOutput = newOutputName(INPUT_FILE, args.export_as_audio,
-                args.export_to_final_cut_pro, making_data_file, False)
 
-            fileFormat = INPUT_FILE[INPUT_FILE.rfind('.'):]
+            INPUT_FILE, chunks, speeds = read_json_cutlist(inp.path, auto_editor.version, log)
+
+            inp = ffmpeg.file_info(INPUT_FILE)
+
+            newOutput = set_output_name(inp.path, args)
         else:
             newOutput = args.output_file[i]
-            if(not os.path.isdir(INPUT_FILE) and '.' not in newOutput):
-                newOutput += INPUT_FILE[INPUT_FILE.rfind('.'):]
+            if(not os.path.isdir(inp.path) and '.' not in newOutput):
+                newOutput = set_output_name(newOutput, args)
 
-        log.debug('Input File: {}'.format(INPUT_FILE))
+        log.debug('Input File: {}'.format(inp.path))
         log.debug('Output File: {}'.format(newOutput))
 
-        if(os.path.isfile(newOutput) and INPUT_FILE != newOutput):
+        if(os.path.isfile(newOutput) and inp.path != newOutput):
             log.debug('Removing already existing file: {}'.format(newOutput))
             os.remove(newOutput)
 
         if(args.sample_rate is None):
-            sampleRate = ffprobe.getSampleRate(INPUT_FILE)
-            if(sampleRate == 'N/A'):
+            sampleRate = inp.audio_streams[0]['samplerate']
+            if(sampleRate is None):
                 sampleRate = '48000'
-                log.warning("Samplerate wasn't detected, so it will be set "\
-                    "to {}.".format(sampleRate))
         else:
             sampleRate = str(args.sample_rate)
         log.debug('Samplerate: {}'.format(sampleRate))
 
-        if(args.audio_bitrate is None):
-            if(INPUT_FILE.endswith('.mkv')):
-                # audio bitrate not supported in the mkv container.
-                audioBitrate = None
-            else:
-                audioBitrate = ffprobe.getPrettyBitrate(INPUT_FILE, 'a')
-                if(audioBitrate == 'N/A'):
-                    log.warning("Couldn't automatically detect audio bitrate.")
-                    audioBitrate = None
-        else:
-            audioBitrate = args.audio_bitrate
-
-        log.debug('Audio Bitrate: {}'.format(audioBitrate))
-
         audioData = None
-        audioFile = fileFormat in audioExtensions
+        audioFile = inp.ext in audioExtensions
         if(audioFile):
             fps = 30 if args.force_fps_to is None else args.force_fps_to
-            tracks = 1 if args.force_tracks_to is None else args.force_tracks_to
-
-            def convertAudio(input_file, output_file, sample_rate, audio_bitrate):
-                cmd = ['-i', input_file]
-                if(not fNone(audio_bitrate)):
-                    cmd.extend(['-b:a', audio_bitrate])
-                cmd.extend(['-ac', '2', '-ar', sample_rate, '-vn', output_file])
-                ffmpeg.run(cmd)
+            tracks = 1
 
             temp_file = os.path.join(TEMP, 'fastAud.wav')
-            convertAudio(INPUT_FILE, temp_file, sampleRate, audioBitrate)
+
+            cmd = ['-i', inp.path]
+            if(not fNone(args.audio_bitrate)):
+                cmd.extend(['-b:a', args.audio_bitrate])
+            cmd.extend(['-ac', '2', '-ar', sampleRate, '-vn', temp_file])
+            ffmpeg.run(cmd)
+
             sampleRate, audioData = read(temp_file)
         else:
             if(args.force_fps_to is not None):
                 fps = args.force_fps_to
             else:
-                fps = ffprobe.getFrameRate(INPUT_FILE)
+                fps = float(inp.fps)
                 if(exporting_to_editor):
                     fps = int(fps)
 
             if(fps < 1):
                 log.error('{}: Frame rate cannot be below 1. fps: {}'.format(
-                    INPUT_FILE, fps))
+                    inp.basename, fps))
 
-            tracks = args.force_tracks_to
-            if(tracks is None):
-                tracks = ffprobe.getAudioTracks(INPUT_FILE)
+            tracks = len(inp.audio_streams)
 
             if(args.cut_by_this_track >= tracks):
                 message = "You choose a track that doesn't exist.\nThere "
@@ -565,11 +538,11 @@ def main():
                 return NumberOfVrfFrames(ffmpeg.pipe(cmd), log) != 0
 
             # Split audio tracks into: 0.wav, 1.wav, etc.
-            cmd = ['-i', INPUT_FILE, '-hide_banner']
+            cmd = ['-i', inp.path, '-hide_banner']
             for t in range(tracks):
                 cmd.extend(['-map', '0:a:{}'.format(t)])
-                if(not fNone(audioBitrate)):
-                    cmd.extend(['-ab', audioBitrate])
+                if(not fNone(args.audio_bitrate)):
+                    cmd.extend(['-ab', args.audio_bitrate])
                 cmd.extend(['-ac', '2', '-ar', sampleRate,
                     os.path.join(TEMP, '{}.wav'.format(t))])
             cmd.extend(['-map', '0:v:0', '-vf', 'vfrdet', '-f', 'null', '-'])
@@ -578,7 +551,7 @@ def main():
 
             if(args.cut_by_all_tracks):
                 temp_file = os.path.join(TEMP, 'combined.wav')
-                cmd = ['-i', INPUT_FILE, '-filter_complex',
+                cmd = ['-i', inp.path, '-filter_complex',
                     '[0:a]amix=inputs={}:duration=longest'.format(tracks), '-ar',
                     sampleRate, '-ac', '2', '-f', 'wav', temp_file]
                 ffmpeg.run(cmd)
@@ -602,8 +575,8 @@ def main():
 
             if('motion' in args.edit_based_on):
                 log.debug('Analyzing video motion.')
-                motionList = motionDetection(INPUT_FILE, ffprobe, args.motion_threshold,
-                    log, width=args.width, dilates=args.dilates, blur=args.blur)
+                motionList = motionDetection(inp, args.motion_threshold, log,
+                    width=args.width, dilates=args.dilates, blur=args.blur)
 
                 if(audioList is not None):
                     if(len(audioList) != len(motionList)):
@@ -648,36 +621,44 @@ def main():
 
         if(args.export_as_json):
             from auto_editor.formats.make_json import make_json_cutlist
-            make_json_cutlist(INPUT_FILE, newOutput, version, chunks, speeds, log)
+            make_json_cutlist(inp.path, newOutput, auto_editor.version, chunks, speeds, log)
             continue
 
         if(args.preview):
             newOutput = None
             from auto_editor.preview import preview
-            preview(INPUT_FILE, chunks, speeds, fps, audioFile, log)
+            preview(inp, chunks, speeds, log)
             continue
 
         if(args.export_to_premiere or args.export_to_resolve):
             from auto_editor.formats.premiere import premiere_xml
-            premiere_xml(INPUT_FILE, TEMP, newOutput, ffprobe, clips, chunks, tracks,
-                sampleRate, audioFile, args.export_to_resolve, fps, log)
+            premiere_xml(inp, TEMP, newOutput, clips, chunks, sampleRate, audioFile,
+                args.export_to_resolve, fps, log)
             continue
 
         if(args.export_to_final_cut_pro):
             from auto_editor.formats.final_cut_pro import fcp_xml
-            fcp_xml(INPUT_FILE, TEMP, newOutput, ffprobe, clips, chunks, tracks,
+
+            totalFrames = chunks[len(chunks) - 1][1]
+            fcp_xml(inp, TEMP, newOutput, clips, chunks, tracks, totalFrames,
                 sampleRate, audioFile, fps, log)
             continue
 
-        def makeAudioFile(input_, chunks, output):
+        if(args.export_to_shotcut):
+            from auto_editor.formats.shotcut import shotcut_xml
+
+            shotcut_xml(inp, TEMP, newOutput, clips, chunks, fps, log)
+            continue
+
+        def makeAudioFile(inp, chunks, output):
             from auto_editor.fastAudio import fastAudio, handleAudio, convertAudio
-            theFile = handleAudio(ffmpeg, input_, audioBitrate, str(sampleRate),
+            theFile = handleAudio(ffmpeg, inp.path, args.audio_bitrate, str(sampleRate),
                 TEMP, log)
 
             temp_file = os.path.join(TEMP, 'convert.wav')
             fastAudio(theFile, temp_file, chunks, speeds, log, fps,
                 args.machine_readable_progress, args.no_progress)
-            convertAudio(ffmpeg, ffprobe, temp_file, input_, output, args, log)
+            convertAudio(ffmpeg, temp_file, inp, output, args.audio_codec, log)
 
         if(audioFile):
             if(args.export_as_clip_sequence):
@@ -685,14 +666,13 @@ def main():
                 for item in chunks:
                     if(speeds[item[2]] == 99999):
                         continue
-                    makeAudioFile(INPUT_FILE, [item],
-                        appendFileName(newOutput, '-{}'.format(i)))
+                    makeAudioFile(inp, [item], appendFileName(newOutput, '-{}'.format(i)))
                     i += 1
             else:
-                makeAudioFile(INPUT_FILE, chunks, newOutput)
+                makeAudioFile(inp, chunks, newOutput)
             continue
 
-        def makeVideoFile(input_, chunks, output):
+        def makeVideoFile(inp, chunks, output):
             from auto_editor.videoUtils import handleAudioTracks, muxVideo
             continueVid = handleAudioTracks(ffmpeg, output, args, tracks, chunks,
                 speeds, fps, TEMP, log)
@@ -718,16 +698,14 @@ def main():
                             'av render method.')
 
                     from auto_editor.renderVideo import renderAv
-                    renderAv(ffmpeg, ffprobe, input_, args, chunks, speeds, fps,
-                        has_vfr, TEMP, log)
+                    renderAv(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, TEMP, log)
 
                 if(args.render == 'opencv'):
                     from auto_editor.renderVideo import renderOpencv
-                    renderOpencv(ffmpeg, ffprobe, input_, args, chunks, speeds, fps,
-                        has_vfr, effects, TEMP, log)
+                    renderOpencv(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
+                        effects, TEMP, log)
 
                 if(log.is_debug):
-                    log.conwrite('')
                     log.debug('Writing the output file.')
                 else:
                     log.conwrite('Writing the output file.')
@@ -745,11 +723,11 @@ def main():
                 if(speeds[chunk[2]] == 99999):
                     continue
 
-                makeVideoFile(INPUT_FILE, padChunk(chunk, totalFrames),
+                makeVideoFile(inp, padChunk(chunk, totalFrames),
                     appendFileName(newOutput, '-{}'.format(i)))
                 i += 1
         else:
-            makeVideoFile(INPUT_FILE, chunks, newOutput)
+            makeVideoFile(inp, chunks, newOutput)
 
     if(not args.preview and not making_data_file):
         timer.stop()
