@@ -1,13 +1,12 @@
 '''preview.py'''
 
 # Internal Libraries
-import os
 from datetime import timedelta
 
 # Included Libraries
 from auto_editor.usefulFunctions import getNewLength
 
-def printTimeFrame(title: str, frames, fps: float):
+def printTimeFrame(title, frames, fps):
     in_sec = round(frames / fps, 1)
     fps = round(fps)
     if(in_sec < 1):
@@ -17,7 +16,9 @@ def printTimeFrame(title: str, frames, fps: float):
     print('{}: {} secs ({})'.format(title, in_sec, minutes))
 
 
-def preview(myInput, chunks: list, speeds: list, fps: float, audioFile, log):
+def preview(inp, chunks, speeds, log):
+    fps = 30 if inp.fps is None else float(inp.fps)
+
     old_time = chunks[len(chunks)-1][1]
     print('')
     printTimeFrame('Old length', old_time, fps)
@@ -28,31 +29,29 @@ def preview(myInput, chunks: list, speeds: list, fps: float, audioFile, log):
 
     clips = 0
     cuts = 0
-    cutL = []
-    clipLengths = []
+    cut_lens = []
+    clip_lens = []
     for chunk in chunks:
         state = chunk[2]
         if(speeds[state] != 99999):
             clips += 1
             leng = (chunk[1] - chunk[0]) / speeds[state]
-            clipLengths.append(leng)
+            clip_lens.append(leng)
         else:
             cuts += 1
             leng = chunk[1] - chunk[0]
-            cutL.append(leng)
+            cut_lens.append(leng)
 
-    print('Number of clips:', clips)
-    printTimeFrame('Smallest clip length', min(clipLengths), fps)
-    printTimeFrame('Largest clip length', max(clipLengths), fps)
-    printTimeFrame('Average clip length', sum(clipLengths) / len(clipLengths), fps)
-    print('\nNumber of cuts:', cuts)
+    print('Number of clips: {}'.format(clips))
+    printTimeFrame('Smallest clip length', min(clip_lens), fps)
+    printTimeFrame('Largest clip length', max(clip_lens), fps)
+    printTimeFrame('Average clip length', sum(clip_lens) / len(clip_lens), fps)
+    print('\nNumber of cuts: {}'.format(cuts))
 
-    if(cutL != []):
-        printTimeFrame('Smallest cut length', min(cutL), fps)
-        printTimeFrame('Largest cut length', max(cutL), fps)
-        printTimeFrame('Average cut length', sum(cutL) / len(cutL), fps)
+    if(cut_lens != []):
+        printTimeFrame('Smallest cut length', min(cut_lens), fps)
+        printTimeFrame('Largest cut length', max(cut_lens), fps)
+        printTimeFrame('Average cut length', sum(cut_lens) / len(cut_lens), fps)
         print('')
 
-    if(not audioFile):
-        print('Video framerate:', fps)
-    log.debug(f'Chunks:\n{chunks}')
+    log.debug('Chunks:\n{}'.format(chunks))
